==> php54-owncloud-8.0.0.tgz: share/owncloud/apps/files_sharing/l10n/es.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Compartir entre servidores no está habilitado en este servidor",
    "The mountpoint name contains invalid characters." : "El punto de montaje contiene caracteres inválidos.",
    "Invalid or untrusted SSL certificate" : "Certificado SSL inválido o no confiable",
    "Could not authenticate to remote share, password might be wrong" : "No se ha podido autenticar para compartir remotamente, quizás esté mal la contraseña",
    "Storage not valid" : "Almacenamiento inválido",
    "Couldn't add remote share" : "No se puede añadir un compartido remoto",
    "Shared with you" : "Compartido contigo",
    "Shared with others" : "Compartido con otros",
    "Shared by link" : "Compartido por medio de enlaces",
    "Nothing shared with you yet" : "Todavía no han compartido nada contigo",
    "Files and folders others share with you will show up here" : "Aquí aparecerán archivos y carpetas que otros compartan contigo",
    "Nothing shared yet" : "Aún no hay nada compartido",
    "Files and folders you share will show up here" : "Aquí aparecerán archivos y carpetas que usted comparta con otros",
    "No shared links" : "No hay enlaces compartidos",
    "Files and folders you share by link will show up here" : "Aquí aparecerán archivos y carpetas que usted comparta mediante un enlace",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "¿Desea añadir el recurso compartido remoto {name} de {owner}@{remote}?",
    "Remote share" : "Recurso compartido remoto",
    "Remote share password" : "Contraseña del compartido remoto",
    "Cancel" : "Cancelar",
    "Add remote share" : "Añadir recurso compartido remoto",
    "No ownCloud installation (7 or higher) found at {remote}" : "No se encontró una instalación de ownCloud (7 o mayor) en {remote}",
    "Invalid ownCloud url" : "URL de ownCloud inválido",
    "Share" : "Compartir",
    "Shared by" : "Compartido por",
    "A file or folder was shared from <strong>another server</strong>" : "Se ha compartido un archivo o carpeta desde <strong>otro servidor</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Ha sido <strong>descargado</strong> un archivo (o carpeta) compartido públicamente",
    "You received a new remote share from %s" : "Ha recibido un nuevo recurso compartido remoto de %s",
    "%1$s accepted remote share %2$s" : "%1$s aceptó el recurso compartido remoto %2$s",
    "%1$s declined remote share %2$s" : "%1$s ha rechazado el recurso compartido remoto %2$s",
    "%1$s unshared %2$s from you" : "%1$s dejó de compartirse %2$s por ti",
    "Public shared folder %1$s was downloaded" : "Se descargó la carpeta pública compartida %1$s",
    "Public shared file %1$s was downloaded" : "Se descargó el archivo público compartido %1$s",
    "This share is password-protected" : "Este elemento compartido esta protegido por contraseña",
    "The password is wrong. Try again." : "La contraseña introducida es errónea. Inténtelo de nuevo.",
    "Password" : "Contraseña",
    "No entries found in this folder" : "No hay entradas en esta carpeta",
    "Name" : "Nombre",
    "Share time" : "Compartido hace",
    "Sorry, this link doesn’t seem to work anymore." : "Vaya, este enlace parece que no volverá a funcionar.",
    "Reasons might be:" : "Las causas podrían ser:",
    "the item was removed" : "el elemento fue eliminado",
    "the link expired" : "el enlace expiró",
    "sharing is disabled" : "compartir está desactivado",
    "For more info, please ask the person who sent this link." : "Para mayor información, contacte a la persona que le envió el enlace.",
    "Add to your ownCloud" : "Agregue su propio ownCloud",
    "Download" : "Descargar",
    "Download %s" : "Descargar %s",
    "Direct link" : "Enlace directo",
    "Federated Cloud Sharing" : "Compartido en Cloud Federado",
    "Allow users on this server to send shares to other servers" : "Permitir a usuarios de este servidor compartir con usuarios de otros servidores",
    "Allow users on this server to receive shares from other servers" : "Permitir a usuarios de este servidor recibir archivos de usuarios de otros servidores"
},
"nplurals=2; plural=(n != 1);");

==> php54-owncloud-8.1.0.tgz: share/owncloud/apps/files_sharing/l10n/es.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Compartir entre servidores no está habilitado en este servidor",
    "The mountpoint name contains invalid characters." : "El punto de montaje contiene caracteres inválidos.",
    "Invalid or untrusted SSL certificate" : "Certificado SSL inválido o no confiable",
    "Could not authenticate to remote share, password might be wrong" : "No se ha podido autenticar para compartir remotamente, quizás esté mal la contraseña",
    "Storage not valid" : "Almacenamiento inválido",
    "Couldn't add remote share" : "No se puede añadir un compartido remoto",
    "Shared with you" : "Compartido contigo",
    "Shared with others" : "Compartido con otros",
    "Shared by link" : "Compartido por medio de enlaces",
    "Nothing shared with you yet" : "Todavía no han compartido nada contigo",
    "Files and folders others share with you will show up here" : "Aquí aparecerán archivos y carpetas que otros compartan contigo",
    "Nothing shared yet" : "Aún no hay nada compartido",
    "Files and folders you share will show up here" : "Aquí aparecerán archivos y carpetas que usted comparta con otros",
    "No shared links" : "No hay enlaces compartidos",
    "Files and folders you share by link will show up here" : "Aquí aparecerán archivos y carpetas que usted comparta mediante un enlace",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "¿Desea añadir el recurso compartido remoto {name} de {owner}@{remote}?",
    "Remote share" : "Recurso compartido remoto",
    "Remote share password" : "Contraseña del compartido remoto",
    "Cancel" : "Cancelar",
    "Add remote share" : "Añadir recurso compartido remoto",
    "You can upload into this folder" : "Usted puede cargar en esta carpeta",
    "No ownCloud installation (7 or higher) found at {remote}" : "No se encontró una instalación de ownCloud (7 o mayor) en {remote}",
    "Invalid ownCloud url" : "URL de ownCloud inválida",
    "Share" : "Compartir",
    "Shared by" : "Compartido por",
    "A file or folder has been <strong>shared</strong>" : "Se ha <strong>compartido</strong> un archivo o carpeta",
    "A file or folder was shared from <strong>another server</strong>" : "Se ha compartido un archivo o carpeta desde <strong>otro servidor</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Ha sido <strong>descargado</strong> un archivo (o carpeta) compartido públicamente",
    "You received a new remote share from %s" : "Ha recibido un nuevo recurso compartido remoto de %s",
    "%1$s accepted remote share %2$s" : "%1$s aceptó el recurso compartido remoto %2$s",
    "%1$s declined remote share %2$s" : "%1$s ha rechazado el recurso compartido remoto %2$s",
    "%1$s unshared %2$s from you" : "%1$s dejó de compartirse %2$s por ti",
    "Public shared folder %1$s was downloaded" : "Se descargó la carpeta pública compartida %1$s",
    "Public shared file %1$s was downloaded" : "Se descargó el archivo público compartido %1$s",
    "You shared %1$s with %2$s" : "Usted compartió %1$s con %2$s",
    "You shared %1$s with group %2$s" : "Usted ha compartido %1$s con el grupo %2$s",
    "%2$s shared %1$s with you" : "%2$s ha compartido %1$s con usted",
    "You shared %1$s via link" : "Ha compartido %1$s vía enlace",
    "Shares" : "Compartidos",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Compartirlo conmigo a través de mi ID Nube Federada #ownCloud, ver %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Compartirlo conmigo a través de mi ID Nube Federada #ownCloud",
    "This share is password-protected" : "Este elemento compartido está protegido por contraseña",
    "The password is wrong. Try again." : "La contraseña introducida es errónea. Inténtelo de nuevo.",
    "Password" : "Contraseña",
    "No entries found in this folder" : "No hay entradas en esta carpeta",
    "Name" : "Nombre",
    "Share time" : "Compartido hace",
    "Sorry, this link doesn’t seem to work anymore." : "Vaya, este enlace parece que no volverá a funcionar.",
    "Reasons might be:" : "Las causas podrían ser:",
    "the item was removed" : "el elemento fue eliminado",
    "the link expired" : "el enlace expiró",
    "sharing is disabled" : "compartir está desactivado",
    "For more info, please ask the person who sent this link." : "Para mayor información, contacte a la persona que le envió el enlace.",
    "Add to your ownCloud" : "Agregue su propio ownCloud",
    "Download" : "Descargar",
    "Download %s" : "Descargar %s",
    "Direct link" : "Enlace directo",
    "Federated Cloud Sharing" : "Compartido en Cloud Federado",
    "Open documentation" : "Documentación abierta",
    "Allow users on this server to send shares to other servers" : "Permitir a usuarios de este servidor compartir con usuarios de otros servidores",
    "Allow users on this server to receive shares from other servers" : "Permitir a usuarios de este servidor recibir archivos de usuarios de otros servidores",
    "Federated Cloud" : "Nube Federada",
    "Your Federated Cloud ID:" : "Su ID Nube Federada:",
    "Share it:" : "Compartir:",
    "Add it to your website:" : "Agregarlo a su sitio de internet:",
    "Share with me via ownCloud" : "Compartirlo conmigo vía OwnCloud",
    "HTML Code:" : "Código HTML:"
},
"nplurals=2; plural=(n != 1);");
